#include <stdint.h>

#include "irq.h"
#include "rc5.h"
#include "timer.h"
#include "disp.h"
#include "key.h"
#include "clock.h"

void main_10ms(void)
{
	struct rc5_data telegram;

	/* Check if new telegram has been received */
	if (rc5_recv(&telegram)) {
		/* Pass it to the key detector */
		key_on_data(&telegram);
	}
}

int main(void)
{
	/* Initialize modules */
	rc5_init();
	timer_init();
	disp_init();
	key_init();
	clock_init();

	/* Enable interrupts for timer */
	irq_enable();
	
	/* Main loop to dispatch timer jobs */
	for (;;)
	{
		timer_dispatch();
	}
}
